@@ -14,7 +14,7 @@ abline(0,1)
 res.dev.mu <- sqrt(x$deviance.mu)*ifelse(x$z_es>=0,1,-1)   
 ry <- c(min(res.dev.mu,-3.5),max(res.dev.mu,3.5))               
 if(x$censored==FALSE) plot(x$mu.fitted,res.dev.mu, ylim=ry, cex=0.3, lwd=3, main="Median submodel", ylab="Deviance-type residual", xlab="Fitted values")                                 
-else{plot(x$mu.fitted[x$event==0],res.dev.mu[x$event==0], xlim=range(x$mu.fitted), ylim=ry, cex=0.3, lwd=3, main="Median submodel", ylab="Deviance-type residual", xlab="Fitted values")
+if(x$censored!=FALSE) {plot(x$mu.fitted[x$event==0],res.dev.mu[x$event==0], xlim=range(x$mu.fitted), ylim=ry, cex=0.3, lwd=3, main="Median submodel", ylab="Deviance-type residual", xlab="Fitted values")
 par(new=TRUE)
 plot(x$mu.fitted[x$event==1],res.dev.mu[x$event==1], xlim=range(x$mu.fitted), ylim=ry, pch="+", main="Median submodel", ylab="Deviance-type residual", xlab="Fitted values")} 
 abline(h=-3,lty=3)                                              
@@ -23,7 +23,7 @@ abline(h=+3,lty=3)
 res.dev.phi <- sqrt(x$deviance.phi)*ifelse(x$z_es>=0,1,-1) 
 ry <- c(min(res.dev.phi,-3.5),max(res.dev.phi,3.5))             
 if(x$censored==FALSE) plot(x$phi.fitted,res.dev.phi, ylim=ry, cex=0.3, lwd=3, main="Skewness/Dispersion submodel", ylab="Deviance-type residual", xlab="Fitted values")                                 
-else{plot(x$phi.fitted[x$event==0],res.dev.phi[x$event==0], xlim=range(x$phi.fitted), ylim=ry, cex=0.3, lwd=3, main="Skewness/Dispersion submodel", ylab="Deviance-type residual", xlab="Fitted values")
+if(x$censored!=FALSE) {plot(x$phi.fitted[x$event==0],res.dev.phi[x$event==0], xlim=range(x$phi.fitted), ylim=ry, cex=0.3, lwd=3, main="Skewness/Dispersion submodel", ylab="Deviance-type residual", xlab="Fitted values")
 par(new=TRUE)
 plot(x$phi.fitted[x$event==1],res.dev.phi[x$event==1], xlim=range(x$phi.fitted), ylim=ry, pch="+", main="Skewness/Dispersion submodel", ylab="Deviance-type residual", xlab="Fitted values")} 
 abline(h=-3,lty=3)                                              
